"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var fs_1 = __importDefault(require("fs"));
var webpack_merge_1 = require("webpack-merge");
var pnp_webpack_plugin_1 = __importDefault(require("pnp-webpack-plugin"));
var getOutput_1 = __importDefault(require("./getOutput"));
var getLoaders_1 = __importDefault(require("./getLoaders"));
var getPlugins_1 = __importDefault(require("./getPlugins"));
var getOptimization_1 = __importDefault(require("./getOptimization"));
var mock_1 = __importDefault(require("./middleware/mock"));
var logger_1 = __importDefault(require("./middleware/logger"));
var utils_1 = __importDefault(require("./utils"));
var paths_1 = __importDefault(require("./paths"));
var entry = ['./src/index'];
function getExtraWebpackConfig(webpackConfig) {
    var path = '';
    if (utils_1.default.isDev()) {
        path = paths_1.default.getResolvePath('webpack.config.dev.js');
    }
    if (utils_1.default.isProduction()) {
        path = paths_1.default.getResolvePath('webpack.config.prod.js');
    }
    if (!(path && fs_1.default.existsSync(path))) {
        var webpackConfig_1 = paths_1.default.getResolvePath('webpack.config.js');
        if (webpackConfig_1 && fs_1.default.existsSync(webpackConfig_1)) {
            path = webpackConfig_1;
        }
    }
    if (!path) {
        return {};
    }
    try {
        var config = utils_1.default.requireModule(path);
        if (typeof config === 'function') {
            return config(webpackConfig);
        }
        return config;
    }
    catch (e) {
        return {};
    }
}
var HOST = '127.0.0.1';
var PORT = 3000;
exports.default = (function (rcb, options) {
    var devServerConfig = {
        host: rcb.host || HOST,
        port: rcb.port || PORT,
        proxy: rcb.proxy,
        quiet: true,
        overlay: true,
        disableHostCheck: true,
        historyApiFallback: {
            htmlAcceptHeaders: ['text/html', 'application/xhtml+xml', 'application/xml']
        },
        compress: true,
        clientLogLevel: 'warn',
        hot: true,
        inline: true,
        watchOptions: {
            ignored: /node_modules/
        },
        open: rcb.open === false ? rcb.open : true,
        setup: function (app) {
            var mockConfig = rcb.mock;
            if ((options === null || options === void 0 ? void 0 : options.mock) && mockConfig) {
                // mock代理的url不会在node中log出来，只有proxy代理的url才会log方便查看是哪里出了问题
                app.use(mockConfig.api, mock_1.default.middleware(rcb.mock));
            }
            app.use(logger_1.default());
        }
    };
    var defaultWebpackConfig = {
        mode: utils_1.default.getEnv(),
        performance: {
            hints: false
        },
        devServer: utils_1.default.isDev() ? devServerConfig : undefined,
        devtool: utils_1.default.isDev() ? 'cheap-module-eval-source-map' : false,
        entry: entry,
        output: getOutput_1.default(),
        module: {
            rules: getLoaders_1.default(rcb)
        },
        optimization: getOptimization_1.default(),
        plugins: getPlugins_1.default(rcb),
        resolve: {
            alias: rcb.alias,
            plugins: [pnp_webpack_plugin_1.default],
            extensions: ['.js', '.jsx', '.es6', '.json', '.ts', '.tsx']
        },
        resolveLoader: {
            plugins: [
                pnp_webpack_plugin_1.default.moduleLoader(module)
            ]
        }
    };
    return webpack_merge_1.merge(defaultWebpackConfig, rcb.webpack || {}, getExtraWebpackConfig(defaultWebpackConfig));
});
